@@ -8,6 +8,7 @@ pub mod flags;
 pub mod bitwise;
 pub mod shifts;
 pub mod concat;
+pub mod bitwise_map;
 
 pub fn register_arithm_module<'a>(_py: Python<'a>) -> PyResult<&'a PyModule> {
     let arithm = PyModule::new(_py, "arithm")?;
@@ -51,5 +52,7 @@ pub fn register_arithm_module<'a>(_py: Python<'a>) -> PyResult<&'a PyModule> {
 
     arithm.add_function(wrap_pyfunction!(concat::concat, arithm)?)?;
 
+    arithm.add_function(wrap_pyfunction!(bitwise_map::bitwise_map, arithm)?)?;
+
     return Ok(arithm);
 }
\ No newline at end of file
